class ActionType():
    DECIMAL = "decimal"
    ASCII = "ascii"
    EQUALS = "equals"
    BITEQUALS = "bitequals"
    BINARY = "binary"
    HEXDUMP = "hexdump"
    DOSDATE = "dosdate"
    DOSTIME = "dostime"
    UNICODE = "unicode"